---
template: mainpanel
source_form: markdown
name: What Job Does This Do?
updated: September 2016
title: What Job Does This Do?
---
### What job does / will this do?

The aim of this project is to allow adults and children to write code in a
familiar high level language that can then be compiled to run on an arbitrary
embedded system - that is devices with very low power CPUs and very little memory.
(ie devices too small to host a python interpreter/runtime) 

It's pre-alpha at the moment. However, as of Sept 2016, it's beginning to be
usable for compiling very simple python programs that can run directly on an
arduino, starting with those that can control servos.  This means small
python powered robots :)

It will be useful in supporting things like the The Scout Association's "Digital
Maker" badge. That's a fair way off though.
